@@ -24,8 +24,8 @@
 #include "GLTTboolean.h"
 #endif
 
-struct _TT_Engine;
-typedef struct _TT_Engine TT_Engine;
+struct TT_Engine_;
+typedef struct TT_Engine_ TT_Engine;
 
 /////////////////////////////////////////////////////////////////////////////
 
